@@ -6,7 +6,7 @@
 
 # Standard library imports.
 from os.path import abspath
-from StringIO import StringIO
+from io import BytesIO
 import copy
 import numpy
 
@@ -136,7 +136,7 @@ class TestContour(TestCase):
         # Test if saving a visualization and restoring it works.
 
         # Save visualization.
-        f = StringIO()
+        f = BytesIO()
         f.name = abspath('test.mv2') # We simulate a file.
         script.save_visualization(f)
         f.seek(0) # So we can read this saved data.
