@@ -2,7 +2,7 @@
 
 """
 # Author: Prabhu Ramachandran <prabhu_r@users.sf.net>
-# Copyright (c) 2005, Enthought, Inc.
+# Copyright (c) 2005-2016, Enthought, Inc.
 # License: BSD Style.
 
 # Enthought library imports.
@@ -93,6 +93,7 @@ class Actor(Component):
                (len(self.inputs[0].outputs) == 0):
             return
 
+        self.configure_input(self.mapper, self.inputs[0].outputs[0])
         self._tcoord_generator_mode_changed(self.tcoord_generator_mode)
         self.render()
 
@@ -194,14 +195,15 @@ class Actor(Component):
             return False
         if not isinstance(source, Source):
             return False
-        if source.outputs[0].is_a('vtkImageData'):
+        if source.get_output_dataset().is_a('vtkImageData'):
             return True
         return False
 
     def _change_texture_input(self):
         if self._can_object_give_image_data(self.texture_source_object):
-            self.configure_connection(self.texture,
-                                      self.texture_source_object)
+            self.configure_connection(
+                self.texture, self.texture_source_object
+            )
             self.actor.texture = self.texture
         else:
             self.texture_source_object = None
@@ -250,9 +252,8 @@ class Actor(Component):
             tg = tg_dict[value]()
             self.tcoord_generator = tg
             self.configure_connection(tg, inp[0])
-            self.configure_connection(self.mapper, inp[0])
+            self.configure_connection(self.mapper, tg)
         tg = self.tcoord_generator
         if tg is not None:
             tg.on_trait_change(self.render)
         self.render()
-
