@@ -7,7 +7,7 @@ a convenient option to create "filled contours".
 
 """
 # Author: Prabhu Ramachandran <prabhu_r@users.sf.net>
-# Copyright (c) 2005, Enthought, Inc.
+# Copyright (c) 2005-2016, Enthought, Inc.
 # License: BSD Style.
 
 # Standard library imports.
@@ -176,7 +176,7 @@ class Contour(Component):
             self.contours = [(cr[0] + cr[1])/2]
             self.minimum_contour = cr[0]
             self.maximum_contour = cr[1]
-        self.outputs = [cf.output]
+        self.outputs = [cf]
 
     def update_data(self):
         """Override this method to do what is necessary when upstream
@@ -229,7 +229,8 @@ class Contour(Component):
         if not self.auto_update_range:
             return
         src = get_module_source(self.inputs[0])
-        sc = src.outputs[0].point_data.scalars
+        dataset = self._get_source_dataset(src)
+        sc = dataset.point_data.scalars
         if sc is not None:
             sc_array = sc.to_array()
             has_nan = numpy.isnan(sc_array).any()
@@ -289,7 +290,7 @@ class Contour(Component):
         cf = self._set_contour_input()
         # This will trigger a change.
         self._auto_contours_changed(self.auto_contours)
-        self.outputs = [cf.output]
+        self.outputs = [cf]
 
     def _get_contour_filter(self):
         if self.filled_contours:
@@ -305,9 +306,9 @@ class Contour(Component):
         cf = self.contour_filter
         if self.filled_contours:
             inp = convert_to_poly_data(inp)
-            self.configure_input_data(cf, inp)
+            self.configure_input(cf, inp)
         else:
-            self.configure_connection(cf, self.inputs[0])
+            self.configure_input(cf, inp)
         cf.update()
         return cf
 
@@ -336,3 +337,10 @@ class Contour(Component):
     def _get__default_contour(self):
         return (self._data_min + self._data_max)*0.5
 
+
+    def _get_source_dataset(self, src):
+        o = src.outputs[0]
+        if o.is_a('vtkDataSet'):
+            return o
+        elif hasattr(o, 'output'):
+            return o.output
