@@ -13,7 +13,7 @@ from apptools.persistence import state_pickler
 
 # Local imports.
 from mayavi.core.component import Component
-from mayavi.core.common import error 
+from mayavi.core.common import error
 
 
 def _get_extent(inp):
@@ -103,7 +103,7 @@ class GridPlane(Component):
         """
         if len(self.inputs) == 0:
             return
-        input = self.inputs[0].outputs[0]
+        input = self.inputs[0].get_output_dataset()
         plane = None
         if input.is_a('vtkStructuredGrid'):
             plane = tvtk.StructuredGridGeometryFilter()
@@ -115,12 +115,12 @@ class GridPlane(Component):
             msg = "The GridPlane component does not support the %s dataset."\
                   %(input.class_name)
             error(msg)
-            raise TypeError, msg
+            raise TypeError(msg)
 
         self.configure_connection(plane, self.inputs[0])
         self.plane = plane
         self.plane.update()
-        self.outputs = [plane.output]
+        self.outputs = [plane]
         self._update_limits()
         self._update_extents()
         # If the data is 2D make sure that we default to the
