@@ -26,11 +26,14 @@ logger = logging.getLogger(__name__)
 ######################################################################
 # Utility functions.
 ######################################################################
+
+
 def debug(msg):
     """Handle a debug message.
     """
     logger.debug(msg)
 
+
 def warning(msg, parent=None):
     """Handle a warning message.
     """
@@ -38,6 +41,7 @@ def warning(msg, parent=None):
     if pyface is not None:
         pyface.warning(parent, msg)
 
+
 def error(msg, parent=None):
     """Handle an error message.
     """
@@ -45,6 +49,7 @@ def error(msg, parent=None):
     if pyface is not None:
         pyface.error(parent, msg)
 
+
 def exception(msg='Exception', parent=None):
     """This function handles any exception derived from Exception and
     prints out an error.  The optional `parent` argument is passed
@@ -65,6 +70,7 @@ def exception(msg='Exception', parent=None):
     finally:
         type = value = tb = None # clean up
 
+
 def process_ui_events():
     """Process GUI events.
 
@@ -74,6 +80,7 @@ def process_ui_events():
     if pyface is not None:
         pyface.GUI.process_events()
 
+
 def get_engine(obj):
     """Try and return the engine given an object in the mayavi
     pipeline.  This basically walks up the parent's of the object till
@@ -88,6 +95,15 @@ def get_engine(obj):
     return None
 
 
+def get_output(obj):
+    """Given an object, extracts the output object, hiding differences
+    between old and new pipeline."""
+    if obj.is_a('vtkDataSet'):
+        return obj
+    else:
+        return obj.output
+
+
 def get_object_path(object, parent, path='engine'):
     """Given a mayavi object on the tree view, this should find its
     "path" with respect to the parent object that contains it.
