@@ -4,7 +4,7 @@ Rectilinear.
 
 """
 # Author: Prabhu Ramachandran <prabhu@aero.iitb.ac.in>
-# Copyright (c) 2007, Enthought, Inc.
+# Copyright (c) 2007-2015, Enthought, Inc.
 # License: BSD Style.
 
 # Enthought library imports.
@@ -152,12 +152,12 @@ class ExtractGrid(FilterBase):
         if len(inputs) == 0:
             return
 
-        input = inputs[0].outputs[0]
+        input = inputs[0].get_output_dataset()
         mapping = {'vtkStructuredGrid': tvtk.ExtractGrid,
                    'vtkRectilinearGrid': tvtk.ExtractRectilinearGrid,
                    'vtkImageData': tvtk.ExtractVOI}
 
-        for key, klass in mapping.iteritems():
+        for key, klass in mapping.items():
             if input.is_a(key):
                 self.filter = klass()
                 break
@@ -170,7 +170,7 @@ class ExtractGrid(FilterBase):
         self.configure_connection(fil, inputs[0])
         fil.update_whole_extent()
         fil.update()
-        self._set_outputs([fil.output])
+        self._set_outputs([fil])
         self._update_limits()
         self._update_voi()
         self._update_sample_rate()
