@@ -1,13 +1,13 @@
 """
 mlab: a simple scripting interface to Mayavi2 for 3D plotting.
 
-Can be used inside Mayavi2 itself, in "ipython -wthread", or in any
-application with the WxWidget mainloop running.
+Can be used inside Mayavi2 itself, in "ipython --gui=qt", or in any
+application with a compatible UI (Qt or wxPython).
 """
 
 # Author: Prabhu Ramachandran <prabhu_r@users.sf.net>
 #         Gael Varoquaux <gael dot varoquaux at normalesup dot org>
-# Copyright (c) 2007-2010, Enthought, Inc.
+# Copyright (c) 2007-2016, Enthought, Inc.
 # License: BSD Style.
 
 
@@ -40,7 +40,7 @@ def show_engine():
                     'show_pipeline', stacklevel=2)
     return show_pipeline()
 
-from tools.helper_functions import contour3d, test_contour3d, \
+from .tools.helper_functions import contour3d, test_contour3d, \
     quiver3d, test_quiver3d, test_quiver3d_2d_data, \
     points3d, test_points3d, test_molecule, \
     flow, test_flow, \
@@ -55,13 +55,15 @@ from tools.helper_functions import contour3d, test_contour3d, \
     test_barchart, test_mesh_mask_custom_colors
 
 
-from tools.decorations import colorbar, scalarbar, vectorbar, \
+from .tools.decorations import colorbar, scalarbar, vectorbar, \
     outline, axes, xlabel, ylabel, zlabel, text, title, \
     orientation_axes, text3d
 
-import tools.pipeline as pipeline
+from .tools import pipeline
 
-from tools.tools import start_recording, stop_recording
+from .tools.tools import start_recording, stop_recording
+
+from .tools.notebook import init as init_notebook
 
 if __name__ == "__main__":
     import numpy
