@@ -173,7 +173,7 @@ class Streamline(Module):
         # Setup the radius/width of the tube/ribbon filters based on
         # given input.
         if self._first:
-            b = src.outputs[0].bounds
+            b = src.get_output_dataset().bounds
             l = [(b[1]-b[0]), (b[3]-b[2]), (b[5]-b[4])]
             length = sqrt(l[0]*l[0] + l[1]*l[1] + l[2]*l[2])
             self.ribbon_filter.width = length*0.0075
@@ -239,7 +239,7 @@ class Streamline(Module):
 
         # A default output so there are no pipeline errors.  The
         # update_pipeline call corrects this if needed.
-        self.outputs = [new.output]
+        self.outputs = [new]
 
         self.update_pipeline()
 
