@@ -3,9 +3,10 @@ pickled or persisted, it saves the data given to it in the form of a
 gzipped string.
 """
 # Author: Prabhu Ramachandran <prabhu_r@users.sf.net>
-# Copyright (c) 2005-2008, Enthought, Inc.
+# Copyright (c) 2005-2015, Enthought, Inc.
 # License: BSD Style.
 
+import sys
 import os
 import tempfile
 
@@ -24,7 +25,8 @@ from mayavi.core.common import handle_children_state
 from mayavi.core.trait_defs import DEnum
 from mayavi.core.pipeline_info import (PipelineInfo,
         get_tvtk_dataset_name)
-from vtk_xml_file_reader import get_all_attributes
+from .utils import has_attributes
+from .vtk_xml_file_reader import get_all_attributes
 
 
 ######################################################################
@@ -56,18 +58,6 @@ def write_dataset_to_string(data):
     w.global_warning_display = warn
     return sdata
 
-def has_attributes(dataset):
-    """Returns `True` when the given TVTK `dataset` has any attribute
-    arrays in point and cell data and `False` otherwise.
-    """
-    pd = dataset.point_data
-    if pd is not None and pd.number_of_arrays > 0:
-        return True
-    cd = dataset.cell_data
-    if cd is not None and cd.number_of_arrays > 0:
-        return True
-    return False
-
 
 ######################################################################
 # `VTKDataSource` class
@@ -171,14 +161,20 @@ class VTKDataSource(Source):
         data = self.data
         if data is not None:
             sdata = write_dataset_to_string(data)
-            z = gzip_string(sdata)
+            if sys.version_info[0] > 2:
+                z = gzip_string(sdata.encode('ascii'))
+            else:
+                z = gzip_string(sdata)
             d['data'] = z
         return d
 
     def __set_pure_state__(self, state):
         z = state.data
         if z is not None:
-            d = gunzip_string(z)
+            if sys.version_info[0] > 2:
+                d = gunzip_string(z).decode('ascii')
+            else:
+                d = gunzip_string(z)
             r = tvtk.DataSetReader(read_from_input_string=1,
                                    input_string=d)
             warn = r.global_warning_display
@@ -334,7 +330,7 @@ class VTKDataSource(Source):
             aa = obj._assign_attribute
             data = getattr(obj.data, '%s_data'%d_type)
             for attr in attrs:
-                values = attributes[attr]
+                values = sorted(attributes[attr])
                 values.append('')
                 setattr(obj, '_%s_%s_list'%(d_type, attr), values)
                 if len(values) > 1:
