@@ -2,7 +2,7 @@
 
 """
 # Author: Prabhu Ramachandran <prabhu_r@users.sf.net>
-# Copyright (c) 2005-2008, Enthought, Inc.
+# Copyright (c) 2005-2015, Enthought, Inc.
 # License: BSD Style.
 
 # Standard library imports.
@@ -15,7 +15,8 @@ from tvtk.api import tvtk
 # Local imports.
 from mayavi.core.pipeline_info import (PipelineInfo,
         get_tvtk_dataset_name)
-from vtk_xml_file_reader import VTKXMLFileReader
+from .utils import has_attributes
+from .vtk_xml_file_reader import VTKXMLFileReader
 
 
 ########################################################################
@@ -55,7 +56,7 @@ class VTKFileReader(VTKXMLFileReader):
     def get_output_object(self):
         """ Return the reader output port."""
         return self.reader.output_port
-    
+
     ######################################################################
     # Non-public interface
     ######################################################################
@@ -75,23 +76,25 @@ class VTKFileReader(VTKXMLFileReader):
                 n = self.reader.number_of_outputs
             except AttributeError: # for VTK >= 4.5
                 n = self.reader.number_of_output_ports
-            outputs = []
-            for i in range(n):
-                outputs.append(self.reader.get_output(i))
-            self.outputs = outputs
 
-            # FIXME: Only the first output goes through the assign
-            # attribute filter.
-            aa = self._assign_attribute
-            self.configure_input_data(aa, outputs[0])
-            self.update_data()
-            aa.update()
-            outputs[0] = aa.output
+            if n > 0:
+                outputs = []
+                for i in range(n):
+                    outputs.append(self.reader.get_output(i))
 
-            self.outputs = outputs
+                # FIXME: currently handling only one output (the first one)
+                # with assign attributes.
+                if has_attributes(outputs[0]):
+                    aa = self._assign_attribute
+                    self.configure_input_data(aa, outputs[0])
+                    self.update_data()
+                    aa.update()
+                    outputs[0] = aa.output
 
-            # FIXME: The output info is only based on the first output.
-            self.output_info.datasets = [get_tvtk_dataset_name(outputs[0])]
+                self.outputs = outputs
+
+                # FIXME: The output info is only based on the first output.
+                self.output_info.datasets = [get_tvtk_dataset_name(outputs[0])]
 
             # Change our name on the tree view
             self.name = self._get_name()
@@ -107,4 +110,3 @@ class VTKFileReader(VTKXMLFileReader):
             ret += ' [Hidden]'
 
         return ret
-
