@@ -8,11 +8,12 @@
 from os.path import basename
 
 # Enthought library imports.
-from traits.api import Instance, List, Str, Bool
+from traits.api import Instance, List, Str, Bool, Button
 from traitsui.api import View, Group, Item, Include
 from tvtk.api import tvtk
 
 # Local imports.
+from mayavi.core.common import error
 from mayavi.core.file_data_source import FileDataSource
 from mayavi.core.trait_defs import DEnum
 from mayavi.core.pipeline_info import (PipelineInfo,
@@ -133,6 +134,8 @@ class VTKXMLFileReader(FileDataSource):
     # The VTK data file reader.
     reader = Instance(tvtk.XMLReader)
 
+    refresh = Button('Update reader')
+
     # Information about what this object can produce.
     output_info = PipelineInfo(datasets=['any'],
                                attribute_types=['any'],
@@ -147,6 +150,7 @@ class VTKXMLFileReader(FileDataSource):
                       Item(name='cell_vectors_name'),
                       Item(name='cell_tensors_name'),
                       Item(name='reader'),
+                      Item(name='refresh', show_label=False)
                       ))
 
     ########################################
@@ -377,3 +381,6 @@ class VTKXMLFileReader(FileDataSource):
 
         return ret
 
+    def _refresh_fired(self):
+        self.reader.modified()
+        self.update_data()
