@@ -4,7 +4,7 @@
 
 # Standard library imports.
 from os.path import abspath
-from StringIO import StringIO
+from io import BytesIO
 import copy
 import unittest
 import numpy
@@ -61,7 +61,7 @@ class DataReaderTestBase(unittest.TestCase):
     def check_saving(self, engine, scene, bounds, error = 1.01e-02):
 
         # Save visualization.
-        f = StringIO()
+        f = BytesIO()
         f.name = abspath('test.mv2') # We simulate a file.
         engine.save_visualization(f)
         f.seek(0) # So we can read this saved data.
