@@ -1,11 +1,12 @@
 # Author: Suyog Dutt Jain <suyog.jain@aero.iitb.ac.in>
 #         Prabhu Ramachandran <prabhu_r@users.sf.net>
-# Copyright (c) 2008,  Enthought, Inc.
+# Copyright (c) 2008-2015,  Enthought, Inc.
 # License: BSD Style.
 
 # Standard library imports.
 from os.path import abspath
-from StringIO import StringIO
+from io import BytesIO
+import platform
 import copy
 import numpy
 import unittest
@@ -137,6 +138,7 @@ class TestGlyph(unittest.TestCase):
         "Test if the test fixture works"
         self.check()
 
+    @unittest.skipIf(platform.system() == "Darwin", "Test crashes on OSX. See issue #373")
     def test_mask_input_points_with_random_mode(self):
         """Test if masking input points works with random mode.
            Tests Issue #165"""
@@ -177,14 +179,12 @@ class TestGlyph(unittest.TestCase):
         v.implicit_plane = ip
         self.check()
 
-
-
     def test_save_and_restore(self):
         """Test if saving a visualization and restoring it works."""
         engine = self.e
         scene = self.scene
         # Save visualization.
-        f = StringIO()
+        f = BytesIO()
         f.name = abspath('test.mv2') # We simulate a file.
         engine.save_visualization(f)
         f.seek(0) # So we can read this saved data.
