@@ -5,11 +5,12 @@ This also tests some numerics with VTK.
 """
 
 import unittest
+import mock
 
 import numpy as np
+from traits.testing.unittest_tools import UnittestTools
 
 from mayavi import mlab
-from mayavi.core.null_engine import NullEngine
 from mayavi.core.engine import Engine
 from tvtk.api import tvtk
 from mayavi.tools.engine_manager import engine_manager
@@ -26,20 +27,20 @@ class TestMlabNullEngine(unittest.TestCase):
 
     def setUp(self):
         mlab.options.backend = 'test'
-        e = NullEngine()
-        e.start()
-        mlab.set_engine(e)
+        e = mlab.get_engine()
         self.e = e
 
     def tearDown(self):
         # Check that the NullEngine is still the mlab engine
-        if not mlab.get_engine() is self.e:
-            raise AssertionError, \
-                    "The NullEngine has been overridden"
+        current_engine = mlab.get_engine()
+        engine_overridden = not current_engine is self.e
         engine_manager.current_engine = None
-        # Unregistering the engine, to avoid side-effects between tests
         self.e.stop()
         registry.unregister_engine(self.e)
+        if engine_overridden:
+            current_engine.stop()
+            registry.unregister_engine(current_engine)
+            raise AssertionError("The NullEngine has been overridden")
 
 
 ################################################################################
@@ -55,7 +56,7 @@ class TestMlabNullEngineMisc(TestMlabNullEngine):
         src = mlab.pipeline.scalar_field(a)
         filter = mlab.pipeline.contour(src)
 
-        x, y, z = filter.outputs[0].points.to_array().T
+        x, y, z = filter.get_output_dataset().points.to_array().T
 
         # Check that the contour filter indeed did its work:
         np.testing.assert_almost_equal(x, [ 2. ,  2. ,  1.5,  2.5,  2. ,  2. ])
@@ -64,7 +65,7 @@ class TestMlabNullEngineMisc(TestMlabNullEngine):
 
         # Check that the filter was not added to a live scene:
         if filter.scene is not None:
-            raise AssertionError, "The NullEngine seems not to work"
+            raise AssertionError("The NullEngine seems not to work")
 
     def test_user_defined_filter(self):
         x, y, z = np.random.random((3, 100))
@@ -72,7 +73,7 @@ class TestMlabNullEngineMisc(TestMlabNullEngine):
         density = mlab.pipeline.user_defined(src, filter='GaussianSplatter')
 
         self.assertEqual(len(density.outputs), 1)
-        self.assert_(isinstance(density.outputs[0], tvtk.ImageData))
+        self.assertTrue(isinstance(density.get_output_dataset(), tvtk.ImageData))
 
     def test_mlab_source(self):
         """ Check that the different objects created by mlab have an
@@ -115,54 +116,54 @@ class TestMlabNullEngineMisc(TestMlabNullEngine):
         # Test when specifying figure instances
         f1 = mlab.figure()
         e = mlab.get_engine()
-        self.assert_(e.current_scene is f1)
+        self.assertTrue(e.current_scene is f1)
         f2 = mlab.figure()
-        self.assert_(e.current_scene is f2)
+        self.assertTrue(e.current_scene is f2)
         mlab.figure(f1)
-        self.assert_(e.current_scene is f1)
+        self.assertTrue(e.current_scene is f1)
 
         # Test when specifying figure numbers
         f1 = mlab.figure(3)
-        self.assert_(e.current_scene is f1)
+        self.assertTrue(e.current_scene is f1)
         f2 = mlab.figure(4)
-        self.assert_(e.current_scene is f2)
+        self.assertTrue(e.current_scene is f2)
         mlab.figure(3)
-        self.assert_(e.current_scene is f1)
+        self.assertTrue(e.current_scene is f1)
 
         # Test when specifying figure names
         f1 = mlab.figure('Test 1')
-        self.assert_(e.current_scene is f1)
+        self.assertTrue(e.current_scene is f1)
         f2 = mlab.figure('Test 2')
-        self.assert_(e.current_scene is f2)
+        self.assertTrue(e.current_scene is f2)
         mlab.figure('Test 1')
-        self.assert_(e.current_scene is f1)
+        self.assertTrue(e.current_scene is f1)
 
     def test_close(self):
         """ Various tests for mlab.close().
         """
         f = mlab.figure()
-        self.assert_(f.running)
+        self.assertTrue(f.running)
         mlab.close(f)
         self.assertFalse(f.running)
 
         f = mlab.figure(314)
-        self.assert_(f.running)
+        self.assertTrue(f.running)
         mlab.close(314)
         self.assertFalse(f.running)
 
         f = mlab.figure('test_figure')
-        self.assert_(f.running)
+        self.assertTrue(f.running)
         mlab.close('test_figure')
         self.assertFalse(f.running)
 
         f = mlab.figure()
-        self.assert_(f.running)
+        self.assertTrue(f.running)
         mlab.close()
         self.assertFalse(f.running)
 
         figs = [mlab.figure() for i in range(5)]
         for f in figs:
-            self.assert_(f.running)
+            self.assertTrue(f.running)
         mlab.close(all=True)
         for f in figs:
             self.assertFalse(f.running)
@@ -211,18 +212,18 @@ class TestMlabNullEngineMisc(TestMlabNullEngine):
 ################################################################################
 class TestMlabPipeline(TestMlabNullEngine):
     """ Test the pipeline functions.
-        For vtk versions greater than 5.6 (5.10.1 onwards), widgets need
+        For vtk versions greater than 5.10, widgets need
         a render window interactor to be set, otherwise an error is raised.
         As such this test checks for the current VTK version and setups a real
-        engine for vtk > 5.6 and null engine otherwise.
+        engine for vtk > 5.10 and null engine otherwise.
     """
 
     def setUp(self):
         ver = tvtk.Version()
-        self.less_than_vtk_5_6 = True
-        if ver.vtk_major_version >= 5 and ver.vtk_minor_version >= 10:
-            self.less_than_vtk_5_6 = False
-        if self.less_than_vtk_5_6:
+        self.less_than_or_equal_to_vtk_5_10 = True
+        if ver.vtk_major_version >= 5 and ver.vtk_minor_version > 10:
+            self.less_than_or_equal_to_vtk_5_10 = False
+        if self.less_than_or_equal_to_vtk_5_10:
             super(TestMlabPipeline, self).setUp()
         else:
             e = Engine()
@@ -230,12 +231,12 @@ class TestMlabPipeline(TestMlabNullEngine):
             mlab.set_engine(e)
 
     def tearDown(self):
-        if self.less_than_vtk_5_6:
-            super(TestMlabPipeline, self).setUp()
-        else:            
-            for engine in registry.engines.keys():
+        if self.less_than_or_equal_to_vtk_5_10:
+            super(TestMlabPipeline, self).tearDown()
+        else:
+            for engine in list(registry.engines.keys()):
                 registry.unregister_engine(engine)
-    
+
     def test_probe_data(self):
         """ Test probe_data
         """
@@ -261,7 +262,7 @@ class TestMlabPipeline(TestMlabNullEngine):
 ################################################################################
 # class `TestMlabHelperFunctions`
 ################################################################################
-class TestMlabHelperFunctions(TestMlabNullEngine):
+class TestMlabHelperFunctions(TestMlabNullEngine, UnittestTools):
     """ Test various behaviors of the mlab helper functions.
     """
 
@@ -282,6 +283,19 @@ class TestMlabHelperFunctions(TestMlabNullEngine):
         # This should work.
         obj = mlab.imshow(s)
 
+    def test_imshow_extent(self):
+        mlab.imshow(np.random.rand(10, 20),
+                    extent=[-1, 11, -1, 21, 0, 0])
+
+    def test_imshow_colormap(self):
+        # Check if the pipeline is refreshed when we change colormap.
+        # See issue #262
+        a = np.random.random_integers(0, 10, (100, 100))
+
+        actor = mlab.imshow(a, colormap="cool")
+
+        with self.assertTraitChanges(actor, 'pipeline_changed'):
+            actor.module_manager.scalar_lut_manager.lut_mode = 'jet'
 
 ################################################################################
 # class `TestMlabModules`
@@ -372,5 +386,33 @@ class TestMlabModules(TestMlabNullEngine):
                          'scale_by_vector_components')
 
 
+################################################################################
+# class `TestMlabAnimate`
+################################################################################
+class TestMlabAnimate(TestMlabNullEngine):
+
+    def test_animate_sets_up_movie_maker(self):
+        # Given
+        @mlab.animate
+        def anim():
+            for i in range(5): yield
+
+        self.e.new_scene()
+        from mayavi.tests.test_file_timestep import make_mock_scene
+        self.e.current_scene.scene = make_mock_scene()
+        mm = self.e.current_scene.scene.movie_maker
+
+        # When
+        from mayavi.core.file_data_source import NoUITimer
+        with mock.patch('mayavi.tools.animator.Timer', NoUITimer):
+            a = anim()
+            a.timer.Start()
+
+        # Then
+        mm.animation_start.assert_called_once_with()
+        self.assertEqual(mm.animation_step.call_count, 4)
+        mm.animation_stop.assert_called_once_with()
+
+
 if __name__ == '__main__':
     unittest.main()
