@@ -5,14 +5,14 @@
 # Standard library imports.
 import unittest
 
-# Local imports.
-from common import get_example_data
-
 # Enthought library imports
 from tvtk.common import is_old_pipeline
 from mayavi.sources.unstructured_grid_reader import UnstructuredGridReader
 from mayavi.tests.data_reader_test_base import DataReaderTestBase
 
+# Local imports.
+from mayavi.tests.common import get_example_data
+
 old_pipeline = is_old_pipeline()
 
 class TestAVSUCDReader(DataReaderTestBase):
