@@ -15,7 +15,7 @@ from mayavi.core.engine import Engine
 from mayavi.core.off_screen_engine import OffScreenEngine
 from mayavi.core.null_engine import NullEngine
 from mayavi.core.common import process_ui_events
-from preferences_mirror import PreferencesMirror
+from .preferences_mirror import PreferencesMirror
 
 # The mlab options.
 options = PreferencesMirror()
@@ -80,16 +80,20 @@ class EngineManager(HasTraits):
             engines = list((self.current_engine,))
         else:
             engines = list()
-        engines.extend(registry.engines.values())
-        if options.backend == 'auto':
-            suitable = [e for e in engines
-                                if e.__class__.__name__ != 'NullEngine']
-        elif options.backend == 'envisage':
+        engines.extend(list(registry.engines.values()))
+        if options.backend == 'envisage':
             suitable = [e for e in engines
                                 if e.__class__.__name__ == 'EnvisageEngine']
         elif options.backend == 'test':
             suitable = [e for e in engines
                                 if e.__class__.__name__ == 'NullEngine']
+        elif options.offscreen:
+            suitable = [e for e in engines
+                                if e.__class__.__name__ == 'OffScreenEngine']
+        elif options.backend == 'auto':
+            suitable = [e for e in engines
+                        if e.__class__.__name__ not in ('NullEngine',
+                                                        'OffScreenEngine')]
         else:
             suitable = [e for e in engines
                                 if e.__class__.__name__ == 'Engine']
@@ -115,7 +119,7 @@ class EngineManager(HasTraits):
             engines = list((self.current_engine,))
         else:
             engines = list()
-        engines.extend(registry.engines.values())
+        engines.extend(list(registry.engines.values()))
         engine = None
         for e in engines:
             if e.__class__.__name__ == 'NullEngine':
