@@ -8,11 +8,10 @@ helper functions.
 
 # Author: Gael Varoquaux <gael.varoquaux@normalesup.org>
 #         Prabhu Ramachandran
-# Copyright (c) 2007-2008, Enthought, Inc.
+# Copyright (c) 2007-2015, Enthought, Inc.
 # License: BSD Style.
 
 import numpy
-import new
 
 from traits.api import Trait, CArray, Instance, CFloat, \
     Any, false, true, TraitTuple, Range, Bool, Property, CInt, Enum, Either
@@ -23,8 +22,9 @@ from tvtk.common import camel2enthought
 from mayavi.core.lut_manager import lut_mode_list
 import mayavi.modules.api as modules
 from mayavi.core.registry import registry
-import tools
-from pipe_base import PipeFactory, make_function
+from . import tools
+from .pipe_base import PipeFactory, make_function
+from .filters import new_class
 
 
 # This the list is dynamically populated further down below at the end.
@@ -709,10 +709,9 @@ def _make_functions(namespace):
             continue
 
         # The class to wrap.
-        klass = new.classobj(class_name,
-                             (_AutomaticModuleFactory,),
-                             {'__doc__': mod.help, }
-                             )
+        klass = new_class(
+            class_name, (_AutomaticModuleFactory,), {'__doc__': mod.help, }
+        )
         klass._metadata = mod
         # The mlab helper function.
         func = make_function(klass)
