@@ -47,6 +47,9 @@ def get_tvtk_name(vtk_name):
 def is_old_pipeline():
     return vtk_major_version < 6
 
+def is_version_7():
+    return vtk_major_version > 6
+
 def is_version_62():
     return vtk_major_version == 6 and vtk_minor_version == 2
 
@@ -85,7 +88,10 @@ def configure_input(inp, op):
             inp.input = op.output
     else:
         if hasattr(op, 'output_port'):
-            inp.input_connection = op.output_port
+            if hasattr(inp, 'input_connection'):
+                inp.input_connection = op.output_port
+            elif hasattr(inp, 'set_input_connection'):
+                inp.set_input_connection(op.output_port)
         elif op.is_a('vtkAlgorithmOutput'):
             inp.input_connection = op
         elif op.is_a('vtkDataSet'):
@@ -109,6 +115,8 @@ def configure_source_data(obj, data):
     else:
         if data.is_a('vtkAlgorithmOutput'):
             obj.set_source_connection(data)
+        elif hasattr(data, 'output_port'):
+            obj.set_source_connection(data.output_port)
         else:
             obj.set_source_data(data)
 
