@@ -7,10 +7,13 @@ functionality. See the class docs for more details.
 
 """
 # Author: Prabhu Ramachandran <prabhu@enthought.com>
-# Copyright (c) 2007-2013, Enthought, Inc.
+# Copyright (c) 2007-2016, Enthought, Inc.
 # License: BSD Style.
 
 
+from __future__ import print_function
+
+import os
 import os.path
 
 from apptools.persistence import state_pickler
@@ -24,6 +27,7 @@ from traits.api import HasPrivateTraits, HasTraits, Any, Int, \
 
 from tvtk.pyface import light_manager
 
+
 VTK_VER = tvtk.Version().vtk_version
 
 
@@ -132,6 +136,9 @@ class TVTKScene(HasPrivateTraits):
     # The light manager.
     light_manager = Instance(light_manager.LightManager, record=True)
 
+    # The movie maker instance.
+    movie_maker = Instance('tvtk.pyface.movie_maker.MovieMaker', record=True)
+
     # Is the scene busy or not.
     busy = Property(Bool, record=False)
 
@@ -233,6 +240,7 @@ class TVTKScene(HasPrivateTraits):
     def _closed_fired(self):
         self.light_manager = None
         self._interactor = None
+        self.movie_maker = None
 
     ###########################################################################
     # 'Scene' interface.
@@ -395,9 +403,10 @@ class TVTKScene(HasPrivateTraits):
                     '.oogl': 'oogl', '.rib': 'rib', '.obj': 'wavefront',
                     '.eps': 'gl2ps', '.pdf':'gl2ps', '.tex': 'gl2ps',
                     '.x3d': 'x3d', '.pov': 'povray'}
-        if ext.lower() not in meth_map.keys():
-            raise ValueError, \
-                  'Unable to find suitable image type for given file extension.'
+        if ext.lower() not in meth_map:
+            raise ValueError(
+                'Unable to find suitable image type for given file extension.'
+            )
         meth = getattr(self, 'save_' + meth_map[ext])
         if size is not None:
             orig_size = self.get_size()
@@ -533,8 +542,9 @@ class TVTKScene(HasPrivateTraits):
             try:
                 Nx, Ny = resolution
             except TypeError:
-                raise TypeError, \
-                      "Resolution (%s) should be a sequence with two elements"%resolution
+                raise TypeError(
+                    "Resolution (%s) should be a sequence with two elements"%resolution
+                )
 
         if len(file_name) == 0:
             return
@@ -639,7 +649,7 @@ class TVTKScene(HasPrivateTraits):
                   "either not supported by your version of VTK or "\
                   "you have not configured VTK to work with GL2PS -- read "\
                   "the documentation for the vtkGL2PSExporter class."
-            print msg
+            print(msg)
             return
 
         if len(file_name) != 0:
@@ -650,7 +660,7 @@ class TVTKScene(HasPrivateTraits):
                 if not isinstance(exp, tvtk.GL2PSExporter):
                     msg = "Need a vtkGL2PSExporter you passed a "\
                           "%s"%exp.__class__.__name__
-                    raise TypeError, msg
+                    raise TypeError(msg)
                 ex.file_prefix = f_prefix
             else:
                 ex = tvtk.GL2PSExporter()
@@ -674,6 +684,10 @@ class TVTKScene(HasPrivateTraits):
                 self._exporter_write(ex)
             else:
                 ex.write()
+            # Work around for a bug in VTK where it saves the file as a
+            # .pdf.gz when the file is really a PDF file.
+            if f_ext == '.pdf' and os.path.exists(f_prefix + '.pdf.gz'):
+                os.rename(f_prefix + '.pdf.gz', file_name)
 
     def save_x3d(self, file_name):
         """Save scene to an X3D file (http://www.web3d.org/x3d/).
@@ -686,7 +700,7 @@ class TVTKScene(HasPrivateTraits):
         if not hasattr(tvtk, 'X3DExporter'):
             msg = "Saving as a X3D file does not appear to be  "\
                   "supported by your version of VTK."
-            print msg
+            print(msg)
             return
 
         if len(file_name) != 0:
@@ -708,7 +722,7 @@ class TVTKScene(HasPrivateTraits):
         if not hasattr(tvtk, 'POVExporter'):
             msg = "Saving as a POVRAY file does not appear to be  "\
                   "supported by your version of VTK."
-            print msg
+            print(msg)
             return
 
         if len(file_name) != 0:
@@ -913,6 +927,11 @@ class TVTKScene(HasPrivateTraits):
             messenger.disconnect(i_vtk, 'EndInteractionEvent',
                                  self._record_camera_position)
 
+    def _movie_maker_default(self):
+        from tvtk.pyface.movie_maker import MovieMaker
+        return MovieMaker(scene=self)
+
+
 ######################################################################
 # `TVTKScene` class.
 ######################################################################
