@@ -5,23 +5,24 @@ make sure that the generated code works well.
 
 """
 # Author: Prabhu Ramachandran
-# Copyright (c) 2004, Enthought, Inc.
+# Copyright (c) 2004-2016, Enthought, Inc.
 # License: BSD Style.
 
 import unittest
-import cPickle
+import pickle
 import weakref
-import new
 import sys
 import gc
 import traceback
 import contextlib
-
+import types
+import inspect
+import re
 import numpy
 import vtk
 
 from tvtk import tvtk_base
-from tvtk.common import get_tvtk_name, configure_input_data
+from tvtk.common import get_tvtk_name, configure_input_data, is_version_7
 
 from traits.api import TraitError
 
@@ -43,6 +44,10 @@ To generate tvtk_classes.zip you must do the following::
 # Only used for testing.
 from tvtk.tvtk_classes import tvtk_helper
 
+PY_VER = sys.version_info[0]
+if PY_VER > 2:
+    long = int
+
 
 def mysum(arr):
     val = arr
@@ -51,6 +56,26 @@ def mysum(arr):
     return val
 
 
+def has_subclass(tvtk_class):
+    """ Return True if `tvtk_class` has a subclass (excluding itself)
+    Unfortunately because of the VTK API we cannot tell whether the
+    subclass is abstract or not
+    """
+    def is_sub_class(x):
+        return (inspect.isclass(x) and
+                issubclass(x, tvtk_class) and
+                x is not tvtk_class)
+    # wish there was an iterator version of inspect.getmembers
+    return bool(inspect.getmembers(tvtk, is_sub_class))
+
+
+def skipUnlessTVTKHasattr(attr):
+    if hasattr(tvtk, attr):
+        return lambda func: func
+    message = "{} is not available on this build of TVTK"
+    return unittest.skip(message.format(attr))
+
+
 class TestTVTK(unittest.TestCase):
     def test_wrap_vtk(self):
         """Test if the wrap_vtk function works."""
@@ -91,8 +116,13 @@ class TestTVTK(unittest.TestCase):
     def test_custom(self):
         """Test if custom modules can be imported."""
 
+        # First clear the cache. Another module may have already imported
+        # the same class and this would compromise the test
+        from tvtk.tvtk_classes import tvtk_helper
+        tvtk_helper._cache.clear()
+
         # Hack to simulate a module inside tvtk.custom.
-        mod = new.module('xml_data_reader')
+        mod = types.ModuleType('xml_data_reader')
 
         class XMLDataReader:
             def f(self):
@@ -103,10 +133,19 @@ class TestTVTK(unittest.TestCase):
         # Now test if this is the one imported.
         r = tvtk.XMLDataReader()
         self.assertEqual(r.f(), 'f')
-        self.assertEqual(r.__class__.__bases__, ())
+        if len(vtk.vtkObjectBase.__bases__) > 0:
+            if is_version_7():
+                expect = ()
+            else:
+                expect = (object,)
+        else:
+            expect = tuple()
+
+        self.assertEqual(r.__class__.__bases__, expect)
 
         # Clean up.
         del sys.modules['tvtk.custom.xml_data_reader']
+        tvtk_helper._cache.clear()
 
     def test_basic(self):
         """Test a simple tvtk pipeline."""
@@ -257,14 +296,14 @@ class TestTVTK(unittest.TestCase):
         """Test if Matrix4x4 works nicely."""
         m = tvtk.Matrix4x4()
         [m.set_element(i, j, i*4 + j) for i in range(4) for j in range(4)]
-        s = cPickle.dumps(m)
+        s = pickle.dumps(m)
         del m
-        m = cPickle.loads(s)
+        m = pickle.loads(s)
         for i in range(4):
             for j in range(4):
                 self.assertEqual(m.get_element(i, j), i*4 + j)
         # Test the from/to_array functions.
-        a = numpy.array(range(16), dtype=float)
+        a = numpy.array(list(range(16)), dtype=float)
         a.shape = 4, 4
         m = tvtk.Matrix4x4()
         m.from_array(a)
@@ -289,9 +328,9 @@ class TestTVTK(unittest.TestCase):
         self.assertEqual(p.color, (0.5, 0.5, 0.5))
 
         # Test pickling.
-        s = cPickle.dumps(p)
+        s = pickle.dumps(p)
         del p
-        p = cPickle.loads(s)
+        p = pickle.loads(s)
         self.assertEqual(p.specular_color, sc)
         self.assertEqual(p.diffuse_color, val)
         self.assertEqual(p.ambient_color, val)
@@ -305,13 +344,13 @@ class TestTVTK(unittest.TestCase):
         points.insert_next_point((0, 1, 2))
         pt = points[0]
         self.assertEqual(pt, (0, 1, 2))
-        ptl = points[0L]
+        ptl = points[long(0)]
         self.assertEqual(ptl, (0, 1, 2))
         get_pt = points.get_point(0)
         self.assertEqual(get_pt, (0, 1, 2))
-        get_ptl = points.get_point(0L)
+        get_ptl = points.get_point(long(0))
         self.assertEqual(get_ptl, (0, 1, 2))
-    
+
     def test_cell_array(self):
         """ Test if cell array insertion updates number of cells.
             Fixes GH Issue 178.
@@ -464,10 +503,13 @@ class TestTVTK(unittest.TestCase):
             self.assertEqual(i, j)
         self.assertEqual(f[-1], 3)
         self.assertEqual(f[0], 0)
-        if type(f[0]) is long:
-            self.assertEqual(repr(f), '[0L, 1L, 2L, 3L]')
-        else:
+        if sys.version_info[0] > 2:
             self.assertEqual(repr(f), '[0, 1, 2, 3]')
+        else:
+            if type(f[0]) is long:
+                self.assertEqual(repr(f), '[0L, 1L, 2L, 3L]')
+            else:
+                self.assertEqual(repr(f), '[0, 1, 2, 3]')
         f.append(4)
         f.extend([5, 6])
         self.assertEqual(len(f), 7)
@@ -582,7 +624,8 @@ class TestTVTK(unittest.TestCase):
 
     def test_parent_child_input(self):
         """Case where parent has GetInput and child SetInput."""
-        if vtk_major_version == 6 and vtk_minor_version > 1:
+        if (vtk_major_version >= 6 and vtk_minor_version > 1) or \
+            vtk_major_version == 7:
             vm = tvtk.SmartVolumeMapper()
         else:
             vm = tvtk.VolumeTextureMapper2D()
@@ -614,6 +657,183 @@ class TestTVTK(unittest.TestCase):
             ('caption', 'GetCaption') in cap._updateable_traits_, True)
         self.assertEqual('caption' in cap._full_traitnames_list_, True)
 
+    def test_spider_plot_actor_set_axis_label(self):
+        """ Test SpiderPlotActor Get/SetAxisLabel works
+        """
+        # SpiderPlotActor.SetAxisLabel accepts two arguments
+        # that are of different type, we need to make sure they
+        # are coded as is
+        actor = tvtk.SpiderPlotActor()
+        actor.set_axis_label(1, 'ss')
+        self.assertEqual(actor.get_axis_label(1), 'ss')
+
+    def test_image_convolve_kernel(self):
+        """ Test that setting the kernels in ImageConvolve works
+        """
+        tvtk_filter = tvtk.ImageConvolve()
+        expected = numpy.arange(9.)
+
+        if vtk_major_version < 6:
+            # Before VTK 6, the ImageConvolve.GetKernel3x3
+            # requires an array as argument
+
+            # Set the kernel
+            tvtk_filter.set_kernel3x3(expected)
+
+            # Get it back
+            result = numpy.empty(9)
+            tvtk_filter.get_kernel3x3(result)
+
+            self.assertTrue(numpy.allclose(result, expected), True)
+
+            with self.assertRaises(TypeError):
+                # VTK Set method raises the TypeError
+                tvtk_filter.set_kernel3x3(range(2))
+
+        else:
+            # Since VTK 6.x, ImageConvolve.GetKernel3x3
+            # can take either no argument or an array
+            # With that change in the API, kernel3x3
+            # is a Trait (similarly for kernel3x3x3, ...)
+            tvtk_filter.kernel3x3 = expected
+
+            # Get it back
+            result = numpy.empty(9)
+            tvtk_filter._vtk_obj.GetKernel3x3(result)
+
+            self.assertTrue(numpy.allclose(result, expected), True)
+
+            # The shape is validated by Trait
+            with self.assertRaises(TraitError):
+                tvtk_filter.kernel3x3 = range(2)
+
+    @skipUnlessTVTKHasattr('DistanceRepresentation2D')
+    def test_distance_representation_2d_point1_world_position(self):
+        """ Test that Position attributes in DistanceRepresentation2D works
+        """
+        tvtk_filter = tvtk.DistanceRepresentation2D()
+        tvtk_filter.instantiate_handle_representation()
+
+        if vtk_major_version < 6:
+            # Before VTK 6, the DistanceRepresentation2D.GetPoint1WorldPosition
+            # requires an array as argument
+
+            # Set the kernel
+            expected = (1, 2, 3)
+            tvtk_filter.set_point1_world_position(expected)
+
+            # Get it back
+            result = numpy.empty(3)
+            tvtk_filter.get_point1_world_position(result)
+
+            self.assertTrue(numpy.allclose(result, expected), True)
+
+            with self.assertRaises(TypeError):
+                # VTK Set method raises the TypeError
+                tvtk_filter.set_point1_world_position(range(2))
+        else:
+            # Since VTK 6.x, DistanceRepresentation2D.GetPoint1WorldPosition
+            # can take either no argument or an array
+            # With that change in the API, point1_world_position
+            # is a Trait (similarly for point2_world_position ...)
+
+            # Set the position
+            expected = (1, 2, 3)
+            tvtk_filter.point1_world_position = expected
+
+            # Get it back
+            result = numpy.empty(3)
+            tvtk_filter._vtk_obj.GetPoint1WorldPosition(result)
+
+            self.assertTrue(numpy.allclose(result, expected), True)
+
+            # The shape is validated by Trait
+            with self.assertRaises(TraitError):
+                tvtk_filter.point1_world_position = range(2)
+
+    @skipUnlessTVTKHasattr('XOpenGLRenderWindow')
+    def test_xopengl_render_window(self):
+        """ Test that setting the position to a render window works
+        Issue #357
+        """
+        window = tvtk.XOpenGLRenderWindow()
+
+        # Setting it to some valid value
+        window.position = (1, 1)
+
+        # But setting to some invalid value outside of update_traits
+        # should fail as long as Traits is doing its job
+        with self.assertRaises(TraitError):
+            window.position = 1
+
+    @unittest.skipIf(vtk_major_version < 6,
+                     ('vtkHardwareSelector.PropColorValue is not available '
+                      'for vtk version < 6'))
+    @skipUnlessTVTKHasattr('HardwareSelector')
+    def test_hardware_selector_prop_color_value(self):
+        """ Test that PropColorValue of HardwareSelector works
+        Issue #360
+        """
+        selector = tvtk.HardwareSelector()
+
+        # Setting it to some valid value
+        selector.prop_color_value = (0.1, 0.4, 0.2)
+
+        # But setting to some invalid value outside of update_traits
+        # should fail as long as Traits is doing its job
+        with self.assertRaises(TraitError):
+            selector.prop_color_value = (-100., 10., 1.)
+
+    @skipUnlessTVTKHasattr('AxesTransformRepresentation')
+    def test_axes_transform_representation_tolerance(self):
+        """ Test the tolerance of AxesTransformRepresentation is set properly
+        """
+        tvtk_obj = tvtk.AxesTransformRepresentation()
+        vtk_obj = vtk.vtkAxesTransformRepresentation()
+
+        self.assertTrue(tvtk_obj.tolerance <= vtk_obj.GetToleranceMaxValue())
+        self.assertTrue(tvtk_obj.tolerance >= vtk_obj.GetToleranceMinValue())
+
+    @skipUnlessTVTKHasattr('ObjectFactory')
+    def test_object_factory_enableflag_api(self):
+        """ Test ObjectFactory Get/SetEnableFlag API
+        """
+        # It is an abstract class, can't instantiate
+        klass = tvtk.ObjectFactory
+
+        if has_subclass(klass):
+            # If we place this check as a unittest.skipIf decorator,
+            # this would cause garbage collection tests in the test suite to fail
+            # as the some classes are kept live
+            raise unittest.SkipTest(('ObjectFactory has a subclass. '
+                                     'This may cause the TVTK API to be different '
+                                     'from if it had not'))
+
+        # The Set/Get methods require many args
+        # they should be coded as such
+        self.assertTrue(hasattr(klass, 'set_enable_flag'))
+        self.assertTrue(hasattr(klass, 'get_enable_flag'))
+
+    @skipUnlessTVTKHasattr('ContextDevice2D')
+    def test_contextdevice2d_matrix_api(self):
+        """ Test ContextDevice2D Get/SetMatrix API
+        """
+        # It is an abstract class, can't instantiate
+        klass = tvtk.ContextDevice2D
+
+        if has_subclass(klass):
+            # If we place this check as a unittest.skipIf decorator,
+            # this would cause garbage collection tests in the test suite to fail
+            # as the some classes are kept live
+            raise unittest.SkipTest(('ContextDevice2D has a subclass. '
+                                     'This may cause the TVTK API to be different '
+                                     'from if it had not'))
+
+        # The Set/Get methods require many args
+        # they should be coded as such
+        self.assertTrue(hasattr(klass, 'set_matrix'))
+        self.assertTrue(hasattr(klass, 'get_matrix'))
+
 
 # This separates out any tests for the entire module that would affect
 # the functioning of the other tests.
@@ -625,34 +845,162 @@ class TestTVTKModule(unittest.TestCase):
 
     def setUp(self):
         vtk.vtkObject.GlobalWarningDisplayOff()
-        self.names = [
-            name for name in dir(vtk)
-            if name.startswith('vtk') and
-            not name.startswith('vtkQt')]
+        self.names = []
+        # Filter the ones that are abstract or not implemented
+        for name in dir(vtk):
+            if (not name.startswith('vtk') or name.startswith('vtkQt') or
+                    len(name) <= 3):
+                continue
+            vtk_klass = getattr(vtk, name)
+            tvtk_klass_name = get_tvtk_name(name)
+            tvtk_klass = getattr(tvtk, tvtk_klass_name, None)
+            if hasattr(vtk_klass, '__bases__') and tvtk_klass is not None:
+                try:
+                    obj = vtk_klass()
+                except (TypeError, NotImplementedError):
+                    continue
+                else:
+                    self.names.append(name)
 
     def test_all_instantiable(self):
         """Test if all the TVTK classes can be instantiated"""
         errors = []
         for name in self.names:
-            klass = getattr(vtk, name)
-            if hasattr(klass, '__bases__') and not issubclass(klass, object):
-                try:
-                    klass()
-                except (TypeError, NotImplementedError):
-                    # These classes are abstract and can't/shouldn't
-                    # be instantiated.
-                    pass
-                else:
-                    tvtk_name = get_tvtk_name(name)
-                    tvtk_klass = getattr(tvtk, tvtk_name)
-                    try:
-                        tvtk_klass()
-                    except TraitError:
-                        errors.append(traceback.format_exc())
+            tvtk_name = get_tvtk_name(name)
+            tvtk_klass = getattr(tvtk, tvtk_name, None)
+            try:
+                tvtk_klass()
+            except TraitError:
+                errors.append(traceback.format_exc())
         if len(errors) > 0:
             message = "Not all classes could be instantiated:\n{0}\n"
             raise AssertionError(message.format(''.join(errors)))
 
+    def test_trait_with_range(self):
+        '''Test if all the attributes with MinValue/MaxValue are traits
+        with Range
+        '''
+        def to_camel_case(text):
+            """ Convert text to CamelCase"""
+            def replace_func(matched):
+                word = matched.group(0).strip("_")
+                return word[0].upper()+word[1:].lower()
+            return re.sub(r'(_?[a-zA-Z]+)', replace_func, text)
+
+        def get_min_max_value(vtk_klass, vtk_attr_name):
+            """ Return (min, max) of a VTK attribute
+
+            If MaxValue or MinValue is not available
+            (None, None) is returned
+            """
+            get_min_method = 'Get' + vtk_attr_name + 'MinValue'
+            get_max_method = 'Get' + vtk_attr_name + 'MaxValue'
+            try:
+                return (getattr(vtk_klass(), get_min_method)(),
+                        getattr(vtk_klass(), get_max_method)())
+            except AttributeError:
+                return None, None
+
+        for name in self.names:
+            vtk_klass = getattr(vtk, name)
+            tvtk_klass_name = get_tvtk_name(name)
+
+            try:
+                obj = getattr(tvtk, tvtk_klass_name)()
+            except Exception:
+                # testing for instantiation is above
+                pass
+
+            for trait_name in obj.editable_traits():
+                vtk_attr_name = to_camel_case(trait_name)
+                min_value, max_value = get_min_max_value(vtk_klass,
+                                                         vtk_attr_name)
+
+                # Explicitly checking for None instead of bool(value)
+                # since min_value/max_value could be int(0)
+                if max_value is not None and min_value is not None:
+                    # If max and min values are defined, setting the trait
+                    # to outside this range should fail
+                    with self.assertRaises(TraitError):
+                        setattr(obj, trait_name, (min_value-1, max_value))
+                    with self.assertRaises(TraitError):
+                        setattr(obj, trait_name, (min_value, max_value+1))
+
+    def test_no_trait_has_ptr_address_as_value(self):
+        '''Test if none of the TVTK classes' traits has a value of "*_p_void"
+        '''
+        errors_trait_is_ptr = []
+        for name in self.names:
+            tvtk_klass_name = get_tvtk_name(name)
+            try:
+                obj = getattr(tvtk, tvtk_klass_name)()
+            except Exception:
+                # testing for instantiation is above
+                pass
+
+            # Had to use `_full_traitnames_list_` instead of calling
+            # editable_traits(), otherwise looping over the trait name
+            # and getting the attribute (getattr) cause Segfault for
+            # AxisActor.title_prop3d, DataSetCellIterator.cell_type
+            # DataSetCellIterator.number_of_points ...etc
+            for trait_name in obj._full_traitnames_list_:
+                try:
+                    trait = getattr(obj, trait_name)
+                except (TypeError, TraitError):
+                    pass  # this is tested in another test
+                else:
+                    if isinstance(trait, str) and trait.endswith('_p_void'):
+                        errors_trait_is_ptr.append(
+                            (tvtk_klass_name, trait_name, trait))
+
+        if errors_trait_is_ptr:
+            message = 'These traits are invalid:\n'
+            message += '\n'.join(('tvtk.{0}.{1} = {2!r}'.format(*error)
+                                  for error in errors_trait_is_ptr))
+            self.fail(message)
+
+    def test_all_traits_can_be_obtained(self):
+        '''Test if all of the traits can be obtained
+        '''
+        errors_getting_trait = []
+        for name in self.names:
+            tvtk_klass_name = get_tvtk_name(name)
+            try:
+                obj = getattr(tvtk, tvtk_klass_name)()
+            except Exception:
+                # testing for instantiation is above
+                pass
+
+            for trait_name in obj._full_traitnames_list_:
+                try:
+                    trait = getattr(obj, trait_name)
+                except Exception as exception:
+                    errors_getting_trait.append(
+                        (tvtk_klass_name, trait_name, str(exception)))
+
+        if errors_getting_trait:
+            message = 'These traits cannot be obtained:\n'
+            message += '\n'.join(('tvtk.{0}.{1} : {2}'.format(*error)
+                                  for error in errors_getting_trait))
+            self.fail(message)
+
+    def test_import_tvtk_does_not_import_gui(self):
+        from subprocess import check_output, STDOUT
+
+        output = check_output(
+            [sys.executable, "-v", "-c",
+             "from tvtk.api import tvtk; p = tvtk.Property()"], stderr=STDOUT
+        )
+        output = output.decode('ascii')
+        self.assertFalse('QtCore' in output)
+        self.assertFalse('wx' in output)
+
+    @unittest.skipIf(PY_VER > 2, "Irrelevant for python 3")
+    def test_unicode_traits(self):
+        reader = tvtk.DelimitedTextReader()
+        self.assertIsInstance(reader.unicode_record_delimiters, unicode)
+        self.assertIsInstance(reader.unicode_string_delimiters, unicode)
+        self.assertIsInstance(reader.unicode_field_delimiters, unicode)
 
 if __name__ == "__main__":
     unittest.main()
