@@ -2,7 +2,7 @@
 
 A utility module that makes VTK/TVTK easier to use from the Python
 interpreter.  For a standalone application simply run this file.  To
-use this under IPython (with -wthread) use the `viewer()` helper
+use this under IPython (with --gui=qt) use the `viewer()` helper
 function or use the `IVTK` class.  The widget can also make use of the
 tvtk pipeline browser.
 
@@ -79,11 +79,23 @@ class SaveImageAction(Action):
 
     def perform(self):
         """Pops up a dialog used to save the scene to an image."""
-        extns = ['*.png', '*.jpg', '*.jpeg', '*.tiff', '*.bmp', '*.ps', '*.eps',
-                 '*.tex', '*.rib', '*.wrl', '*.oogl', '*.pdf', '*.vrml', '*.obj',
-                 '*.iv']
+        extensions = ['*.png', '*.jpg', '*.tiff', '*.bmp', '*.ps',
+                      '*.eps', '*.pdf', '*.tex', '*.rib', '*.wrl',
+                      '*.oogl', '*.vrml', '*.obj', '*.iv', '*.pov',
+                      '*.x3d']
+        descriptions = ["PNG", "JPG", "TIFF", "Bitmap", "PostScript",
+                        "EPS", "PDF", "Tex", "RIB", "WRL",
+                        "Geomview", "VRML", "Wavefront", "Open Inventor",
+                        "Povray", "X3D"]
+        wildcard = ""
+        for description, extension in zip(descriptions, extensions):
+            wildcard += "{} ({})|{}|".format(description,
+                                             extension,
+                                             extension)
+        wildcard += "Determine by extension (*.*)|(*.*)"
+
         dlg = FileDialog(parent=self._window.control, action='save as',
-                wildcard='|'.join(extns), title="Save scene to image")
+                wildcard=wildcard, title="Save scene to image")
         if dlg.open() == OK:
             self._window.scene.save(dlg.path)
 
@@ -465,7 +477,7 @@ def viewer(browser=True, instantiate_gui=False):
 
       If True, create an instance of GUI().  This is useful when this
       function is invoked from within an IPython shell.  OTOH, if this
-      is called from within a wxPython app (or with ipython -wthread)
+      is called from within a wxPython app (or with ipython --gui=qt)
       you don't want to start another GUI instance.
     """
     if instantiate_gui:
