@@ -1,4 +1,4 @@
-""" A module that provides VPython like capabilities.  For more
+"""A module that provides VPython like capabilities.  For more
 details about VPython, refer the official website.
 VPython : http://www.vpython.org/index.html
 
@@ -27,14 +27,11 @@ To see examples of classes and functions look at the `test_*`
 functions at the end of this file. Here is a quick example
 demonstrating how to use visual.
 
-Note: To provide threading support for WXWidgets which are essential
-for all GUI fucntionalities in visual, the visual module should be
-interactively used in ipython only when wthread mode is
-enabled. visual will not work properly in an interactive mode in
-vanilla python interpretor.
-::
+Note: The visual module should be interactively used in ipython only when
+--gui=qt is enabled. `visual` will not work properly in an interactive mode
+with the vanilla python interpretor.  ::
 
-    $ ipython -wthread
+    $ ipython --gui=qt
 
     In [1]: from tvtk.tools import visual
     In [2]: visual.test_sphere()
@@ -43,30 +40,29 @@ vanilla python interpretor.
 
 """
 # Author: Raashid Baig <raashid@aero.iitb.ac.in>
-#         Prabhu Ramachandran <prabhu_r@users.sf.net>
+#         Prabhu Ramachandran <prabhu@aero.iitb.ac.in>
 #
 # License: BSD Style.
-# Version: 1.0
-# Year : 2007
+# Year : 2007-2016
+
+from __future__ import print_function
 
 # Standard library imports.
 import sys
 import numpy
 import time
-from math import sin, cos, pi, sqrt, acos, asin
-from vtk.util import colors as color
+from math import sin, cos, pi, sqrt, acos
 
 # Enthought library imports.
 from traits.api import HasTraits, Trait, Instance, Tuple, Int, \
-     Float, Range, Button, Array, Color, Bool, Any, List, Enum
-from traitsui.api import View, Item, Group, RGBColorEditor, RangeEditor
-from traitsui.message import message
+     Range, Button, Array, Bool, Any, List, Enum
+from traitsui.api import View, Item, Group
 from tvtk.api import tvtk
 from tvtk.tools import ivtk
-from tvtk.common import configure_input_data
+from tvtk.common import configure_input
 from pyface.api import GUI
 from pyface.timer.api import Timer
-from tvtk.tvtk_base import TVTKBase, vtk_color_trait
+from tvtk.tvtk_base import vtk_color_trait
 
 
 
@@ -135,7 +131,7 @@ def show():
     visual program. Note - Don't call this function when running
     visual from ipython iterpretor in an interactive mode
     """
-    if '-wthread' in sys.argv:
+    if '-wthread' in sys.argv or '--gui' in sys.argv:
         pass
     else:
         gui = GUI()
@@ -308,7 +304,7 @@ class VTimer(Timer):
 
     def _close(self):
         self.Stop()
-        print "Stopping iterations since the viewer has been closed."
+        print("Stopping iterations since the viewer has been closed.")
 
     def Notify(self):
         """Overridden to call the given callable.
@@ -465,7 +461,7 @@ class Frame(HasTraits):
         self.arg = list(arguments)
         HasTraits.__init__(self, **traits)
 
-        self.keys = traits.keys()
+        self.keys = list(traits.keys())
 
         self._pos_changed(numpy.array([0.0, 0.0, 0.0]), self.pos)
         self._x_changed(0.0, self.x)
@@ -540,10 +536,10 @@ class Curve(HasTraits):
     #####################################################################
     # Traits definitions
 
-    points = Trait(None, None, Array('d', shape=(None,3)), desc='the points of the curve')
+    points = Array(dtype=float, shape=(None,3), desc='the points of the curve')
     pos = Array(value = (0.0, 0.0, 0.0), desc = 'the curve pos')
     radius = Range(0.0, 1.0e299, value = 0.01, desc = 'the radius of curve tube')
-    axis = Array(value = (1.0, 0.0, 0.0), desc = 'the curve axis')
+    axis = Array(value=(1.0, 0.0, 0.0), desc = 'the curve axis')
     x = Range(-1e299, 1e299, 0.0, desc = 'the X coordinate of curve')
     y = Range(-1e299, 1e299, 0.0, desc = 'the Y coordinate of curve')
     z = Range(-1e299, 1e299, 0.0, desc = 'the Z coordinate of curve')
@@ -577,25 +573,16 @@ class Curve(HasTraits):
     def __init__(self, **traits):
         self.property = self.actor.property
 
-        HasTraits.__init__(self, **traits)
-
-        self._points_changed(self.points)
-        self._color_changed(self.color)
-        self._visibility_changed(self.visibility)
-        self._radius_changed(self.radius)
-        self._axis_changed(numpy.array((1.0, 0.0, 0.0)), self.axis)
-
-        configure_input_data(self.stripper, self.polydata)
-        configure_input_data(self.tube, self.stripper.output)
+        configure_input(self.stripper, self.polydata)
+        configure_input(self.tube, self.stripper)
         self.tube.number_of_sides = 4
         self.tube.capping = 1
 
         m = tvtk.PolyDataMapper()
-        configure_input_data(m, self.tube.output)
+        configure_input(m, self.tube)
         self.actor.mapper = m
         self.stripper.update()
         self.tube.update()
-        self.actor.mapper.update()
         self.property = self.actor.property
         self.property.representation = self.representation
         show_actor(self.actor)
@@ -605,6 +592,18 @@ class Curve(HasTraits):
         self.actor.on_trait_change(self.viewer.scene.render)
         self.tube.on_trait_change(self.viewer.scene.render)
 
+        axis = traits.pop('axis', None)
+        HasTraits.__init__(self, **traits)
+
+        self._points_changed(self.points)
+        self._color_changed(self.color)
+        self._visibility_changed(self.visibility)
+        self._radius_changed(self.radius)
+        if axis is not None:
+            self._axis_changed(numpy.array((1.0, 0.0, 0.0)),
+                               numpy.asarray(axis, dtype=float))
+
+
     ######################################################################
     # Object's public methods
     def append(self, pnt):
@@ -627,7 +626,6 @@ class Curve(HasTraits):
         self.polydata.modified()
         self.stripper.update()
         self.tube.update()
-        self.actor.mapper.update()
         self.viewer.scene.render()
 
     def rotate(self, angle, axis, origin = numpy.array([0.0, 0.0, 0.0])):
@@ -643,7 +641,6 @@ class Curve(HasTraits):
         self.polydata.modified()
         self.stripper.update()
         self.tube.update()
-        self.actor.mapper.update()
         self.render()
 
     def render(self):
@@ -655,6 +652,7 @@ class Curve(HasTraits):
     ######################################################################
     # Non-public methods, Event handlers
     def _points_changed(self, value):
+        self.polydata.lines = None
         self.polydata.points = value
         if value is None:
             np = 0
@@ -694,16 +692,11 @@ class Curve(HasTraits):
         self.polydata.modified()
         self.stripper.update()
         self.tube.update()
-        self.actor.mapper.update()
         self.render()
 
     def _axis_changed(self, old, new):
-        self.points = axis_changed(old, new, self.pos, self.points)
-        self.polydata.points = self.points
-        self.polydata.modified()
-        self.stripper.update()
-        self.tube.update()
-        self.render()
+        pts = axis_changed(old, new, self.pos, self.points)
+        self.points = pts.copy()
 
     def _color_changed(self, value):
         self.actor.property.color = value
@@ -767,38 +760,36 @@ class Ring(HasTraits):
     def __init__(self, **traits):
         self.property = self.actor.property
 
-        HasTraits.__init__(self, **traits)
-
-        self._create_points()
-        self._pos_changed(numpy.array([0.0, 0.0, 0.0]), self.pos)
-        self._x_changed(self.x)
-        self._y_changed(self.y)
-        self._z_changed(self.z)
-        self._color_changed(self.color)
-        self._visibility_changed(self.visibility)
-        self._thickness_changed(self.thickness)
-        self._axis_changed(numpy.array((1.0, 0.0, 0.0)), self.axis)
-
         self.normals = tvtk.PolyDataNormals()
-        configure_input_data(self.normals, self.polydata)
-        configure_input_data(self.tube, self.normals.outputs)
+        configure_input(self.normals, self.polydata)
+        configure_input(self.tube, self.normals)
         self.normals.update()
         self.tube.update()
         self.tube.number_of_sides = 4
         self.tube.capping = 1
 
         m = tvtk.PolyDataMapper()
-        configure_input_data(m, self.tube.outputs)
+        configure_input(m, self.tube)
         self.actor.mapper = m
         self.property = self.actor.property
         self.property.representation = self.representation
-        show_actor(self.actor)
-        self.viewer = get_viewer()
 
+        self.viewer = get_viewer()
         self.property.on_trait_change(self.viewer.scene.render)
         self.actor.on_trait_change(self.viewer.scene.render)
         self.tube.on_trait_change(self.viewer.scene.render)
 
+        HasTraits.__init__(self, **traits)
+
+        self._create_points()
+        self._pos_changed([0.0, 0.0, 0.0], self.pos)
+        self._color_changed(self.color)
+        self._visibility_changed(self.visibility)
+        self._thickness_changed(self.thickness)
+        self._axis_changed(numpy.array((1.0, 0.0, 0.0)), self.axis)
+
+        show_actor(self.actor)
+
     ######################################################################
     # Non-public methods, Event handlers
     def _create_points(self):
@@ -829,7 +820,6 @@ class Ring(HasTraits):
             self.polydata.modified()
             self.normals.update()
             self.tube.update()
-            self.actor.mapper.update()
             self.render()
         else:
             c = self.pos
@@ -841,7 +831,6 @@ class Ring(HasTraits):
             self.polydata.points = self.points
             self.polydata.modified()
             self.normals.update()
-            self.actor.mapper.update()
             self.tube.update()
             self.render()
 
@@ -866,7 +855,6 @@ class Ring(HasTraits):
         self.polydata.modified()
         self.normals.update()
         self.tube.update()
-        self.actor.mapper.update()
         self.render()
 
     def _axis_changed(self, old, new):
@@ -883,11 +871,7 @@ class Ring(HasTraits):
         self.render()
 
     def _visibility_changed(self, value):
-        val = int(value)
-        if (val == 1):
-            self.actor.visibility = 1
-        else:
-            self.actor.visibility = 0
+        self.actor.visibility = value
 
     def _thickness_changed(self, value):
         self.tube.radius = value
@@ -907,7 +891,6 @@ class Ring(HasTraits):
         self.polydata.modified()
         self.normals.update()
         self.tube.update()
-        self.actor.mapper.update()
         self.render()
 
     def render(self):
@@ -961,30 +944,29 @@ class Cone(HasTraits):
     def __init__(self, **traits):
         self.property = self.actor.property
 
+        m = tvtk.PolyDataMapper()
+        configure_input(m, self.polydata)
+        self.actor.mapper = m
+        self.property = self.actor.property
+        self.property.representation = self.representation
+
+        self.viewer = get_viewer() # getting the ivtk viewer
+        self.property.on_trait_change(self.viewer.scene.render)
+        self.actor.on_trait_change(self.viewer.scene.render)
+
         HasTraits.__init__(self, **traits)
 
         self._create_points(self.radius, self.height, self.pos, self.axis)
         self._pos_changed(numpy.array([0.0, 0.0, 0.0]), self.pos)
-        self._x_changed(self.x)
-        self._y_changed(self.y)
-        self._z_changed(self.z)
         self._color_changed(self.color)
 
-        m = tvtk.PolyDataMapper()
-        configure_input_data(m, self.polydata)
-        self.actor.mapper = m
-        self.property = self.actor.property
-        self.property.representation = self.representation
         show_actor(self.actor) # passing the actors function for rendering
-        self.viewer = get_viewer() # getting the ivtk viewer
-
-        self.property.on_trait_change(self.viewer.scene.render)
-        self.actor.on_trait_change(self.viewer.scene.render)
 
     ######################################################################
     # Non-public methods, Event handlers
     def _create_points(self, r, h, c, d):
-        cs = tvtk.ConeSource(radius = r, height = h, center = tuple(c), direction = tuple(d))
+        cs = tvtk.ConeSource(radius=r, height=h, center=tuple(c),
+                             direction=tuple(d))
         cs.update()
         ps = cs.output
 
@@ -1001,14 +983,12 @@ class Cone(HasTraits):
         points, lines = self._create_points(self.radius, self.height, self.pos, self.axis)
         self.polydata.points = points
         self.polydata.modified()
-        self.actor.mapper.update()
         self.render()
 
     def _height_changed(self):
         points, lines = self._create_points(self.radius, self.height, self.pos, self.axis)
         self.polydata.points = points
         self.polydata.modified()
-        self.actor.mapper.update()
         self.render()
 
     def _pos_changed(self, old, new):
@@ -1018,7 +998,6 @@ class Cone(HasTraits):
         points, lines = self._create_points(self.radius, self.height, self.pos, self.axis)
         self.points = points
         self.polydata.modified()
-        self.actor.mapper.update()
         self.render()
 
     def _axis_changed(self):
@@ -1064,7 +1043,6 @@ class Cone(HasTraits):
         self.set(axis = ax, trait_change_notify = False)
         self.polydata.points = self.points
         self.polydata.modified()
-        self.actor.mapper.update()
         self.render()
 
     def render(self):
@@ -1114,20 +1092,11 @@ class Sphere(HasTraits):
     def __init__(self, **traits):
         self.property = self.actor.property
 
-        HasTraits.__init__(self, **traits)
-
-        self._create_points(self.radius, self.pos)
-        self._color_changed(self.color)
-        self._visibility_changed(self.visibility)
-        self._x_changed(self.x)
-        self._y_changed(self.y)
-        self._z_changed(self.z)
-
         self.normals = tvtk.PolyDataNormals()
-        configure_input_data(self.normals, self.polydata)
+        configure_input(self.normals, self.polydata)
         self.normals.update()
         m = tvtk.PolyDataMapper() # the usual vtk pipleine countinuation
-        configure_input_data(m, self.normals.output)
+        configure_input(m, self.normals)
         self.actor.mapper = m
         self.property = self.actor.property
         self.property.representation = self.representation
@@ -1137,11 +1106,21 @@ class Sphere(HasTraits):
         self.property.on_trait_change(self.viewer.scene.render)
         self.actor.on_trait_change(self.viewer.scene.render)
 
+        HasTraits.__init__(self, **traits)
+
+        self._create_points(self.radius, self.pos)
+        self._color_changed(self.color)
+        self._visibility_changed(self.visibility)
+        self._x_changed(self.x)
+        self._y_changed(self.y)
+        self._z_changed(self.z)
+
+
     ######################################################################
     # Non-public methods, Event handlers
     def _create_points(self, r, c):
-        sp = tvtk.SphereSource(radius = r, center = tuple(c), 
-                               phi_resolution = 20, 
+        sp = tvtk.SphereSource(radius = r, center = tuple(c),
+                               phi_resolution = 20,
                                theta_resolution = 20)
         sp.update()
         ps = sp.output
@@ -1268,6 +1247,19 @@ class Cylinder(HasTraits):
     def __init__(self, **traits):
         self.property = self.actor.property
 
+        self.normals = tvtk.PolyDataNormals()
+        configure_input(self.normals, self.polydata)
+        m = tvtk.PolyDataMapper() # the usual vtk pipleine countinuation
+        configure_input(m, self.normals)
+        self.actor.mapper = m
+        self.property = self.actor.property
+        self.property.representation = self.representation
+        show_actor(self.actor) # passing the actors function for rendering
+        self.viewer = get_viewer() # getting the ivtk viewer
+
+        self.property.on_trait_change(self.viewer.scene.render)
+        self.actor.on_trait_change(self.viewer.scene.render)
+
         HasTraits.__init__(self, **traits)
 
         self._create_points(self.radius, self.pos, self.length)
@@ -1278,19 +1270,6 @@ class Cylinder(HasTraits):
         self._y_changed(self.y)
         self._z_changed(self.z)
 
-        self.normals = tvtk.PolyDataNormals()
-        configure_input_data(self.normals, self.polydata)
-        m = tvtk.PolyDataMapper() # the usual vtk pipleine countinuation
-        configure_input_data(m, self.normals.output)
-        self.actor.mapper = m
-        self.property = self.actor.property
-        self.property.representation = self.representation
-        show_actor(self.actor) # passing the actors function for rendering
-        self.viewer = get_viewer() # getting the ivtk viewer
-
-        self.property.on_trait_change(self.viewer.scene.render)
-        self.actor.on_trait_change(self.viewer.scene.render)
-
     ######################################################################
     # Non-public methods, Event handlers
     def _create_points(self, r, c, h):
@@ -1434,6 +1413,17 @@ class Box(HasTraits):
     def __init__(self, **traits):
         self.property = self.actor.property
 
+        m = tvtk.PolyDataMapper() # the usual vtk pipleine countinuation
+        configure_input(m, self.polydata)
+        self.actor.mapper = m
+        self.property = self.actor.property
+        self.property.representation = self.representation
+        show_actor(self.actor) # passing the actors function for rendering
+        self.viewer = get_viewer() # getting the ivtk viewer
+
+        self.property.on_trait_change(self.viewer.scene.render)
+        self.actor.on_trait_change(self.viewer.scene.render)
+
         HasTraits.__init__(self, **traits)
 
         self._create_points(self.size, self.pos)
@@ -1447,17 +1437,6 @@ class Box(HasTraits):
         self._height_changed(self.height)
         self._width_changed(self.width)
 
-        m = tvtk.PolyDataMapper() # the usual vtk pipleine countinuation
-        configure_input_data(m, self.polydata)
-        self.actor.mapper = m
-        self.property = self.actor.property
-        self.property.representation = self.representation
-        show_actor(self.actor) # passing the actors function for rendering
-        self.viewer = get_viewer() # getting the ivtk viewer
-
-        self.property.on_trait_change(self.viewer.scene.render)
-        self.actor.on_trait_change(self.viewer.scene.render)
-
     ######################################################################
     # Non-public methods, Event handlers
     def _create_points(self, s, c):
@@ -1596,22 +1575,11 @@ class Arrow(HasTraits):
     def __init__(self, **traits):
         self.property = self.actor.property
 
-        HasTraits.__init__(self, **traits)
-
-        self._create_points(self.radius_cone, self.length_cone, self.radius_shaft, self.pos)
-        self._color_changed(self.color)
-        self._visibility_changed(self.visibility)
-        self._pos_changed(numpy.array([0.0, 0.0, 0.0]), self.pos)
-        self._x_changed(self.x)
-        self._y_changed(self.y)
-        self._z_changed(self.z)
-        self._axis_changed(numpy.array((1.0, 0.0, 0.0)), self.axis)
-
         self.normals = tvtk.PolyDataNormals()
-        configure_input_data(self.normals, self.polydata)
+        configure_input(self.normals, self.polydata)
         self.normals.update()
         m = tvtk.PolyDataMapper() # the usual vtk pipleine countinuation
-        configure_input_data(m, self.normals.output)
+        configure_input(m, self.normals)
         self.actor.mapper = m
         self.property = self.actor.property
         self.property.representation = self.representation
@@ -1621,10 +1589,20 @@ class Arrow(HasTraits):
         self.property.on_trait_change(self.viewer.scene.render)
         self.actor.on_trait_change(self.viewer.scene.render)
 
+        HasTraits.__init__(self, **traits)
+
+        self._create_points(self.radius_cone, self.length_cone, self.radius_shaft, self.pos)
+        self._color_changed(self.color)
+        self._visibility_changed(self.visibility)
+        self._x_changed(self.x)
+        self._y_changed(self.y)
+        self._z_changed(self.z)
+        self._axis_changed(numpy.array((1.0, 0.0, 0.0)), self.axis)
+
     ######################################################################
     # Non-public methods, Event handlers
     def _create_points(self, rc, lc, rs, ps):
-        asrc = tvtk.ArrowSource(tip_radius = rc, tip_length = lc, shaft_radius = rs)
+        asrc = tvtk.ArrowSource(tip_radius=rc, tip_length=lc, shaft_radius=rs)
         asrc.update()
         ps = asrc.output
         points = ps.points.to_array()
@@ -1768,6 +1746,24 @@ class Helix(HasTraits):
     def __init__(self, **traits):
         self.property = self.actor.property
 
+        self.normals = tvtk.PolyDataNormals()
+        configure_input(self.normals, self.polydata)
+        configure_input(self.tube, self.normals)
+        self.tube.number_of_sides = 4
+        self.tube.capping = 1
+
+        m = tvtk.PolyDataMapper()
+        configure_input(m, self.tube)
+        self.actor.mapper = m
+        self.property = self.actor.property
+        self.property.representation = self.representation
+        show_actor(self.actor)
+        self.viewer = get_viewer()
+
+        self.property.on_trait_change(self.viewer.scene.render)
+        self.actor.on_trait_change(self.viewer.scene.render)
+        self.tube.on_trait_change(self.viewer.scene.render)
+
         HasTraits.__init__(self, **traits)
 
         self._create_points()
@@ -1780,24 +1776,6 @@ class Helix(HasTraits):
         self._thickness_changed(self.thickness)
         self._axis_changed(numpy.array((1.0, 0.0, 0.0)), self.axis)
 
-        self.normals = tvtk.PolyDataNormals()
-        configure_input_data(self.normals, self.polydata)
-        configure_input_data(self.tube, self.normals.output)
-        self.tube.number_of_sides = 4
-        self.tube.capping = 1
-
-        m = tvtk.PolyDataMapper()
-        configure_input_data(m, self.tube.output)
-        self.actor.mapper = m
-        self.property = self.actor.property
-        self.property.representation = self.representation
-        show_actor(self.actor)
-        self.viewer = get_viewer()
-
-        self.property.on_trait_change(self.viewer.scene.render)
-        self.actor.on_trait_change(self.viewer.scene.render)
-        self.tube.on_trait_change(self.viewer.scene.render)
-
     ######################################################################
     # Non-public methods, Event handlers
     def _create_points(self):
@@ -1998,6 +1976,14 @@ class Ellipsoid(HasTraits):
     def __init__(self, **traits):
         self.property = self.actor.property
 
+        self.normals = tvtk.PolyDataNormals()
+        configure_input(self.normals, self.polydata)
+        m = tvtk.PolyDataMapper()
+        configure_input(m, self.normals)
+        self.actor.mapper = m
+        self.property = self.actor.property
+        self.property.representation = self.representation
+
         HasTraits.__init__(self, **traits)
 
         self._create_points(self.radius, self.pos)
@@ -2008,24 +1994,16 @@ class Ellipsoid(HasTraits):
         self._z_changed(self.z)
         self._axis_changed(numpy.array((1.0, 0.0, 0.0)), self.axis)
 
-        self.normals = tvtk.PolyDataNormals()
-        configure_input_data(self.normals, self.polydata)
-        self.normals.update()
-        m = tvtk.PolyDataMapper() # the usual vtk pipleine countinuation
-        configure_input_data(self.normals, self.normals.output)
-        self.actor.mapper = m
-        self.property = self.actor.property
-        self.property.representation = self.representation
         show_actor(self.actor) # passing the actors function for rendering
         self.viewer = get_viewer() # getting the ivtk viewer
-
         self.property.on_trait_change(self.viewer.scene.render)
         self.actor.on_trait_change(self.viewer.scene.render)
 
     ######################################################################
     # Non-public methods, Event handlers
     def _create_points(self, r, c):
-        sp = tvtk.SphereSource(radius = r, center = tuple(c), phi_resolution = 20, theta_resolution = 20)
+        sp = tvtk.SphereSource(radius=r, center=tuple(c),
+                               phi_resolution=20, theta_resolution=20)
         sp.update()
         ps = sp.output
 
@@ -2045,6 +2023,8 @@ class Ellipsoid(HasTraits):
 
     def _size_changed(self, value):
         points, polys = self._create_points(self.radius, self.pos)
+        self.set(length=value[0], height=value[1],  width=value[2],
+                 trait_change_notify=False)
         self.polydata.points = points
         self.polydata.modified()
         self.normals.update()
@@ -2151,56 +2131,13 @@ def rate(arg):
     periodically called via a timer.  This will make your script's UI
     completely interactive.
     """
-    print '*'*80
-    print msg
-    print '*'*80
+    print('*'*80)
+    print(msg)
+    print('*'*80)
 
 
 ############################################################
-####################  Test Functions #######################
-############################################################
-
-def test_sphere():
-    s1 = sphere()
-    s2 = sphere(radius = 1.5, pos = (2, 0, 0), color = (1, 0, 0))
-    s2.edit_traits()
-
-def test_box():
-    b1 = box()
-    b2 = box(center = (2, 0, 0), size = (2, 1, 1), color = (0.5, 0.5, 1.0))
-    b2.edit_traits()
-
-def test_cone():
-    c = cone(pos = (5,0,0), color = (1,1,0), axis = (1,1,0))
-    c.edit_traits()
-
-def test_cylinder():
-    c1 = cylinder()
-    c2 = cylinder(radius = 1.5, pos = (2, 0, 0), color = (1, 0, 0))
-    c2.edit_traits()
-
-def test_arrow():
-    a = arrow()
-    a.edit_traits()
-
-def test_curve():
-    c = curve(points = ([[0,0,0],[1,0,0],[0,1,0],[0,0,1]]))
-    c.edit_traits()
-    return c
-
-def test_ring():
-    r1 = ring()
-    r2 = ring(radius = 1.5, pos = (2,0,0), color = (1,0,0))
-    r2.edit_traits()
-
-def test_helix():
-    h1 = helix()
-    r2 = helix(radius = 0.5, pos = (2,0,0), color = (1,0,0))
-    r2.edit_traits()
-
-def test_ellipsoid():
-    e1 = ellipsoid()
-    e1.edit_traits()
+# Some examples.
 
 def test_remove_actors():
     """Test fuction for testing integrity of remove function for
@@ -2211,11 +2148,11 @@ def test_remove_actors():
     cy = cylinder(resolution = 100, pos = (3, 0, 0), color = (0, 0, 1))
 
     time.sleep(3)
-    print "Removed sphere from scene"
+    print("Removed sphere from scene")
     remove_actor(s)
 
     time.sleep(3)
-    print "Removed cone from cone"
+    print("Removed cone from cone")
     remove_actor(co)
 
 def test_frame():
@@ -2251,9 +2188,9 @@ def test_rotate():
     r.rotate(-90, [0,1,0], [1,0,0])
     points2 = r.points
     if (numpy.allclose(points1, points2)):
-        print "All clear"
+        print("All clear")
     else:
-        print "Test failed"
+        print("Test failed")
     return r
 
 def test_translate():
@@ -2276,7 +2213,7 @@ def test_translate():
     ti = iterate(50, anim)
     ti.edit_traits()
 
-def bounce():
+def test_bounce():
     """This is a basic example function, extending the previous
     example."""
     xlen = 10
@@ -2296,4 +2233,3 @@ def bounce():
     t = iterate(60, anim)
     t.edit_traits()
     return t
-
