@@ -2,10 +2,11 @@
 
 """
 # Author: Prabhu Ramachandran <prabhu_r@users.sf.net>
-# Copyright (c) 2004-2008,  Enthought, Inc.
+# Copyright (c) 2004-2015,  Enthought, Inc.
 # License: BSD Style.
 
-import types
+from __future__ import print_function
+
 import sys
 import weakref
 import os
@@ -14,12 +15,25 @@ import logging
 import vtk
 
 from traits import api as traits
-from traitsui.api import BooleanEditor, RGBColorEditor, FileEditor
-import messenger
+from . import messenger
 
 # Setup a logger for this module.
 logger = logging.getLogger(__name__)
 
+
+def BooleanEditor(*args, **kw):
+    from traitsui.api import BooleanEditor as Editor
+    return Editor(*args, **kw)
+
+def RGBColorEditor(*args, **kw):
+    from traitsui.api import RGBColorEditor as Editor
+    return Editor(*args, **kw)
+
+def FileEditor(*args, **kw):
+    from traitsui.api import FileEditor as Editor
+    return Editor(*args, **kw)
+
+
 ######################################################################
 # The TVTK object cache.
 ######################################################################
@@ -98,7 +112,7 @@ class TVTKObjectCache(weakref.WeakValueDictionary):
 _dummy = None
 # This makes the cache work even when the module is reloaded.
 for name in ['tvtk_base', 'tvtk.tvtk_base']:
-    if sys.modules.has_key(name):
+    if name in sys.modules:
         mod = sys.modules[name]
         if hasattr(mod, '_object_cache'):
             _dummy = mod._object_cache
@@ -158,9 +172,9 @@ class TraitRevPrefixMap(traits.TraitPrefixMap):
 
     def validate(self, object, name, value):
         try:
-            if self._rmap.has_key(value):
+            if value in self._rmap:
                 value = self._rmap[value]
-            if not self._map.has_key( value ):
+            if not value in self._map:
                 match = None
                 n     = len( value )
                 for key in self.map.keys():
@@ -185,26 +199,36 @@ class TraitRevPrefixMap(traits.TraitPrefixMap):
 
 def vtk_color_trait(default, **metadata):
     Range = traits.Range
+
     if default[0] == -1.0:
         # Occurs for the vtkTextProperty's color trait.  Need to work
         # around.
-        return traits.Trait(default, traits.Tuple(*default),
+        return traits.Trait(default,
                             traits.Tuple(Range(0.0, 1.0),
                                          Range(0.0, 1.0),
                                          Range(0.0, 1.0),
                                          editor=RGBColorEditor),
                             **metadata)
-    else:
+    elif type(default[0]) is float:
         return traits.Trait(traits.Tuple(Range(0.0, 1.0, default[0]),
                                          Range(0.0, 1.0, default[1]),
                                          Range(0.0, 1.0, default[2])),
-                            editor=RGBColorEditor, **metadata)
+                            editor=RGBColorEditor,
+                            **metadata)
+    else:
+        return traits.Trait(
+            traits.Tuple(
+                Range(0, 255, default[0]), Range(0, 255, default[1]),
+                Range(0, 255, default[2]), cols=3
+            ),
+            **metadata
+        )
 
 
 # Special cases for the FileName and FilePrefix
-vtk_file_name = traits.Trait(None, None, traits.Str, types.UnicodeType,
+vtk_file_name = traits.Trait(None, None, traits.Str, str,
                              editor=FileEditor)
-vtk_file_prefix = traits.Trait(None, None, traits.Str, types.UnicodeType,
+vtk_file_prefix = traits.Trait(None, None, traits.Str, str,
                                editor=(FileEditor, {'truncate_ext': True}))
 
 # The Property class traits are delegated in the Actors.
@@ -250,6 +274,11 @@ class TVTKBase(traits.HasStrictTraits):
     # The wrapped VTK object.
     _vtk_obj = traits.Trait(None, None, vtk.vtkObjectBase())
 
+    # Stores the names of the traits whose VTK Get methods may return
+    # invalid values (e.g. reference to a point) or uninitialised values
+    # We would try to update but allow it to fail
+    _allow_update_failure_ = traits.Tuple
+
     # Stores the names of the traits that need to be updated.
     _updateable_traits_ = traits.Tuple
 
@@ -350,9 +379,9 @@ class TVTKBase(traits.HasStrictTraits):
             # needs to be updated.
             try:
                 setattr(self, i, dict[i])
-            except traits.TraitError, msg:
-                print "WARNING:",
-                print msg
+            except traits.TraitError as msg:
+                print("WARNING:", end=' ')
+                print(msg)
         self._in_set = 0
 
     def __str__(self):
@@ -394,11 +423,15 @@ class TVTKBase(traits.HasStrictTraits):
             view_filename = os.path.join(viewDir,
                                          module_name + '_view.py')
             result = {}
-            execfile(view_filename, {}, result)
+            exec(
+                compile(
+                    open(view_filename).read(), view_filename, 'exec'
+                ), {}, result
+            )
             for name in names:
                 if name in result:
                     view_elements.content[ name ] = result[name]
-        except Exception, e:
+        except Exception:
             pass
         return view_elements
 
@@ -445,15 +478,28 @@ class TVTKBase(traits.HasStrictTraits):
         vtk.vtkObject.GlobalWarningDisplayOff()
 
         for name, getter in self._updateable_traits_:
+            if name == 'global_warning_display':
+                setattr(self, name, warn)
+                continue
+
             try:
                 val = getattr(vtk_obj, getter)()
             except (AttributeError, TypeError):
+                # Some vtk GetMethod accepts more than 1 arguments
+                # FIXME: If we really want to try harder, we could
+                # pass an empty array to the Get method, some Get
+                # method will populate the array as the return
+                # value (e.g. vtkImageConvolve.GetKernel3x3 and alike)
                 pass
             else:
-                if name == 'global_warning_display':
-                    setattr(self, name, warn)
-                else:
+                try:
                     setattr(self, name, val)
+                except traits.TraitError:
+                    if name in self._allow_update_failure_:
+                        pass
+                    else:
+                        raise
+
         # Reset the warning state.
         vtk.vtkObject.SetGlobalWarningDisplay(warn)
         self._in_set = 0
